<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:java="http://xml.apache.org/xslt/java"
                xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
                xmlns:gslib="http://www.greenstone.org/skinning"
                xmlns:gsf="http://www.greenstone.org/greenstone3/schema/ConfigFormat"
                extension-element-prefixes="java util"
                exclude-result-prefixes="java util gsf">

  <xsl:template name="favicon">
    <link rel="shortcut icon" href="interfaces/{$interface_name}/images/favicon.ico"/>
  </xsl:template>

  <xsl:template name="additionalHeaderContent-interface">
    <link rel="stylesheet" href="interfaces/{$interface_name}/style/custom.css" type="text/css"/>
  </xsl:template>




  <!-- ***** QUICK SEARCH AREA ***** -->
  <!-- Search form should only appear if there's a search (query) service AND it has an index. 
       By default, all collections end up with some query service (default is MGPP) even when they have
       no search indexes, which is why the extra test for the presence of an index/fq-something is necessary. -->
  <xsl:template name="quick-search-area">
    <xsl:if test="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@type='query']">
      <xsl:variable name="subaction" select="/page/pageRequest/@subaction"/>
      <div id="quicksearcharea">
	<xsl:if test="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@name='TextQuery']">
	  <xsl:choose>
	    <xsl:when test="not(page/pageRequest[@action='q']) or /page/pageRequest/paramList/param[@name='qs']/@value = '1'">
	      <form action="{$library_name}/collection/{$collNameChecked}/search/TextQuery">
		<!-- This parameter says that we have come from the quick search area -->
		<input type="hidden" name="qs" value="1"/>
		<input type="hidden" name="rt" value="rd"/>
		<input type="hidden" name="s1.level">
		  <xsl:attribute name="value">
		    <xsl:value-of select="/page/pageResponse/collection/serviceList/service[@name='TextQuery']/paramList/param[@name = 'level']/@default"/>
		  </xsl:attribute>
		</input>
		<xsl:choose>
		  <xsl:when test="/page/pageResponse/service[@name = 'TextQuery']/paramList/param[@name = 'startPage']">
		    <input type="hidden" name="s1.startPage" value="1"/>
		  </xsl:when>
		  <xsl:otherwise>
		    <input type="hidden" name="startPage" value="1"/>
		  </xsl:otherwise>
		</xsl:choose>

		<!-- The query text box -->
		<span class="querybox">
		  <xsl:variable name="qs">
		    <xsl:apply-templates select="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@name='TextQuery']/paramList/param[@name='query']" mode="calculate-default"/>
		  </xsl:variable>
		  <nobr>
		    <xsl:apply-templates select="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@name='TextQuery']/paramList/param[@name='query']">
		      <!--
			  <xsl:with-param name="default" select="java:org.greenstone.gsdl3.util.XSLTUtil.tidyWhitespace($qs, /page/@lang)"/>
		      -->
		      <xsl:with-param name="default" select="normalize-space($qs)"/>
		      
		    </xsl:apply-templates>
		  </nobr>
		</span>
		<!-- The index selection list -->
		<xsl:if test="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@name='TextQuery']/paramList/param[@name='index']/@type = 'enum_single'">
		  <span class="textselect">
		    <xsl:apply-templates select="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@name='TextQuery']/paramList/param[@name='index']">
		      <xsl:with-param name="default">
			<xsl:apply-templates select="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@name='TextQuery']/paramList/param[@name='index']" mode="calculate-default"/>
		      </xsl:with-param>
		      <xsl:with-param name="hideSingle">false</xsl:with-param>
		      <xsl:with-param name="quickSearch">true</xsl:with-param>
		    </xsl:apply-templates>
		  </span>
		</xsl:if>
		<!-- The partition selection list -->						
		<xsl:if test="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@name='TextQuery']/paramList/param[@name='indexSubcollection']/@type = 'enum_single'">
		  <span class="textselect">
		    <xsl:apply-templates select="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@name='TextQuery']/paramList/param[@name='indexSubcollection']">
		      <xsl:with-param name="default">
			<xsl:apply-templates select="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@name='TextQuery']/paramList/param[@name='indexSubcollection']" mode="calculate-default"/>
		      </xsl:with-param>
		      <xsl:with-param name="hideSingle">true</xsl:with-param>
		      <xsl:with-param name="quickSearch">true</xsl:with-param>
		    </xsl:apply-templates>
		  </span>
		</xsl:if>	
		<!-- The language selection list -->						
		<xsl:if test="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@name='TextQuery']/paramList/param[@name='indexLanguage']/@type = 'enum_single'">
		  <span class="textselect">
		    <xsl:apply-templates select="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@name='TextQuery']/paramList/param[@name='indexLanguage']">
		      <xsl:with-param name="default">
			<xsl:apply-templates select="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@name='TextQuery']/paramList/param[@name='indexLanguage']" mode="calculate-default"/>
		      </xsl:with-param>
		      <xsl:with-param name="hideSingle">true</xsl:with-param>
		      <xsl:with-param name="quickSearch">true</xsl:with-param>
		    </xsl:apply-templates>
		  </span>
		</xsl:if>							
		<!-- The submit button (for TextQuery) -->
		<xsl:if test="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@name='TextQuery']">
		  <input type="submit" id="quickSearchSubmitButton">
		    <xsl:attribute name="value">
		      <xsl:value-of select="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@name='TextQuery']/displayItem[@name='submit']"/>
		    </xsl:attribute>
		  </input>
		  <br/>
		</xsl:if>
	      </form>
	    </xsl:when>
	    <xsl:otherwise><br/></xsl:otherwise>
	  </xsl:choose>			
	</xsl:if>
	<!-- The list of other search types -->
	<ul>
	  <xsl:for-each select="/page/pageResponse/collection[@name=$collNameChecked]/serviceList/service[@type='query']">
	    <xsl:if test="/page/pageRequest/paramList/param[@name='qs']/@value = 1 or not(@name = /page/pageRequest/paramList/param[@name='s']/@value)">
	      <!-- **** Customized -->
	      <xsl:if test="@name != 'TextQuery'">

		<li class="ui-state-default ui-corner-all">
		  <a>
		    <xsl:attribute name="href">
		      <xsl:value-of select="$library_name"/>/collection/<xsl:value-of select="$collNameChecked"/>/search/<xsl:value-of select="@name"/>
		    </xsl:attribute>
		    <xsl:value-of select="displayItem[@name='name']"/>
		  </a>
		</li>
	      </xsl:if>
	    </xsl:if>
	  </xsl:for-each>
	</ul>
      </div>
    </xsl:if>
  </xsl:template>
  
</xsl:stylesheet>
