<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:java="http://xml.apache.org/xslt/java"
		xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
		xmlns:gslib="http://www.greenstone.org/skinning"
		xmlns:gsf="http://www.greenstone.org/greenstone3/schema/ConfigFormat"
		extension-element-prefixes="java util"
		exclude-result-prefixes="java util gsf">
  

  <!-- set page title -->
  <xsl:template name="pageTitle"><gslib:collectionNameLinked/><gslib:rightArrow/><gslib:serviceName/></xsl:template>


  <!-- the page content -->
  <xsl:template match="/page/pageResponse">
    <xsl:call-template name="classifierPre"/>
    
    <script type="text/javascript" src="interfaces/{$interface_name}/js/classifier_scripts.js"><xsl:text> </xsl:text></script>
    <script type="text/javascript">$(window).load(openStoredClassifiers);</script>

    <!-- **** Customized **** -->
    <xsl:variable name="clName"><xsl:value-of select="classifier/@name"/></xsl:variable>
    <xsl:variable name="floatRightWidth">
      <xsl:choose>
	<xsl:when test="$clName = 'CL4'">20</xsl:when>
	<xsl:otherwise>20</xsl:otherwise> <!-- used to be 30 -->
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="floatLeftWidth">
      <xsl:choose>
	<xsl:when test="$clName = 'CL4'">58</xsl:when>
	<xsl:otherwise>77</xsl:otherwise> <!-- used to be 67 -->
      </xsl:choose>
    </xsl:variable>

    <!-- **** Customized **** -->
    <div id="float-anchor" style="width: {$floatRightWidth}%; min-width:180px; float:right; margin: 0 0 10px 20px;">

      <!-- this right sidebar -->
      <div id="rightSidebar">
	<xsl:comment>Filler needed for div</xsl:comment>
	<xsl:if test="$berryBasketOn or ($documentBasketOn and (util:contains(/page/pageRequest/userInformation/@groups, 'administrator') or util:contains(/page/pageRequest/userInformation/@groups, 'all-collections-editor') or util:contains(/page/pageRequest/userInformation/@groups, $thisCollectionEditor)))">
	  <xsl:if test="$berryBasketOn">
	    <xsl:call-template name="viewOptions"/>
	    <!-- show the berry basket if it's turned on -->
	    <div class="tableOfContentsContainer" style="position:relative; z-index: 2;"> <!-- **** -->
	      <gslib:berryBasket/>
	      <xsl:text> </xsl:text>
	    </div>
	  </xsl:if>
	  
	  <xsl:if test="$documentBasketOn">
	  <gslib:documentBasket/>
	  <xsl:text> </xsl:text>
	  </xsl:if>
	</xsl:if>
      </div>
    </div>
    
    <!--
	show the clasifier results - 
	you can change the appearance of the results by editing
	the two templates at the bottom of this file
    -->
    <!-- **** Customized **** -->
    <div id="results" style="width: {$floatLeftWidth}%">
      <xsl:variable name="collName"><xsl:value-of select="/page/pageRequest/paramList/param[@name='c']/@value"/></xsl:variable>
      <xsl:variable name="serviceName"><xsl:value-of select="service/@name"/></xsl:variable>
      
      <xsl:call-template name="classifierResultsPre"/>
      
      <xsl:apply-templates select="classifier">
	<xsl:with-param name="collName" select="$collName"/>
	<xsl:with-param name="serviceName" select="$serviceName"/>
      </xsl:apply-templates>
    </div>
    
    <div class="clear"><xsl:text> </xsl:text></div>
  </xsl:template>



  <xsl:template name="viewOptions">

    <div id="viewAndZoomOptions" class="ui-state-default ui-corner-all">
      <ul id="viewOptions">
	
	<!-- Zoom on/off button -->

	  <xsl:if test="not(/page/pageResponse/format[@type='display']/gsf:option[@name='disableZoom']) or /page/pageResponse/format[@type='display']/gsf:option[@name='disableZoom']/@value='false'">

	    <!-- **** Customized **** -->
	    <xsl:variable name="clName"><xsl:value-of select="classifier/@name"/></xsl:variable>
	    <xsl:if test="$clName = 'CL4'">
	      <li id="zoomOptions" style="display:none;">
<!--
		<xsl:attribute name="title"><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'doc.zoomTooltip')"/></xsl:attribute>
-->
		<xsl:attribute name="title">Enable/disable Zoom feature over map</xsl:attribute>
		<img id="zoomToggleImage">
		  <xsl:attribute name="src"><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'zoom_image')"/></xsl:attribute>
		</img>

		<input id="zoomToggle" type="checkbox" checked="checked"/>
		<script type="text/javascript">
		  <xsl:text disable-output-escaping="yes">
		    $("#zoomToggle").change(function()
		    {
		      //console.log("**** zoomToggle.change()");
		      _imageZoomEnabled = $("#zoomToggle").prop("checked");
		      //console.log("**** imageZoomEnable now = " + _imageZoomEnabled);
		    });
		  
		    $("#zoomToggleImage").click(function()
		    {
		      //console.log("**** zoomToggle.click()");
		      $("#zoomToggle").prop("checked", !$("#zoomToggle").prop("checked"));
		      _imageZoomEnabled = $("#zoomToggle").prop("checked");
		      //console.log("**** imageZoomEnable now = " + _imageZoomEnabled);
		    });
		  </xsl:text>
		</script>
	      </li>
	    </xsl:if>
	  </xsl:if>


          <!-- Floating TOC on/off button -->
	    <li id="floatingTOCOptions">
<!--
	      <xsl:attribute name="title"><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'doc.floatingTooltip')"/></xsl:attribute>
-->
	      <xsl:attribute name="title">Fix the berry basket to the right side of the screen</xsl:attribute>
	      <img id="floatTOCToggleImage">
		<xsl:attribute name="src"><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'float_toc_image')"/></xsl:attribute>
	      </img>

	      <input id="floatTOCToggle" type="checkbox"/>
	      <script type="text/javascript">
		<xsl:text disable-output-escaping="yes">
		  $("#floatTOCToggle").prop("checked", false);
		  $("#floatTOCToggle").click(function()
		  {
		    floatMenu($("#floatTOCToggle").prop("checked"));
		  });
		  
		  $("#floatTOCToggleImage").click(function()
		  {
		    $("#floatTOCToggle").prop("checked", !$("#floatTOCToggle").prop("checked"))
		    floatMenu($("#floatTOCToggle").prop("checked"));
		  });
		</xsl:text>
	      </script>
	    </li>
	    <xsl:if test="/page/pageRequest/paramList/param[@name='ftoc']/@value = '1'">
	      <script type="text/javascript">
		<xsl:text disable-output-escaping="yes">
		  $(window).load(function()
		  {
		    $("#floatTOCToggle").prop("checked", true);
		    floatMenu(true);
		  });
		</xsl:text>
	      </script>
	    </xsl:if>
      </ul>
      <div style="clear:both;"><xsl:text> </xsl:text></div>
    </div>
  </xsl:template>
  



  <xsl:template match="classifier">
    <xsl:param name="collName"/>
    <xsl:param name="serviceName"/>
    <div id="classifiers">
      <!-- **** Customized **** -->
      <xsl:variable name="clName"><xsl:value-of select="@name"/></xsl:variable>
      <xsl:choose>
	<xsl:when test="@childType = 'HList'">
	  <xsl:call-template name="HList">
	    <xsl:with-param name='collName' select='$collName'/>
	    <xsl:with-param name='serviceName' select='$serviceName'/>
	  </xsl:call-template>
	</xsl:when>
	<xsl:otherwise>
	  <!-- **** Customized **** -->
	  <div style="position: relative">
	    <xsl:if test="$clName = 'CL4'">
	      <!--
		  width="1380.2666"
		  height="1746.2094"
	      -->
	      <iframe src="interfaces/{$interface_name}/iframe/nz-territories.svg"
		      style="float:right; width: 345px; height: 436px; border: none; ">
		<gsf:comment>filler</gsf:comment>
	      </iframe>
	    </xsl:if>
	    
	    <table id="classifiernodelist">
	      <xsl:text> </xsl:text>
	      <xsl:call-template name="processNodeChildren">
		<xsl:with-param name='collName' select='$collName'/>
		<xsl:with-param name='serviceName' select='$serviceName'/>
	      </xsl:call-template>
	    </table>
	  </div>
	</xsl:otherwise>
      </xsl:choose>
    </div>
  </xsl:template>
  

</xsl:stylesheet>

